@@ -135,7 +135,7 @@ CVisGUIShader *vis_shader = NULL;
 
 
 using namespace ADDON;
-using namespace PLATFORM;
+using namespace P8PLATFORM;
 
 
 class cOSDTexture
@@ -840,6 +840,10 @@ bool cVNSIAdmin::Open(const std::string& hostname, int port, const char* name)
     return false;
   }
 
+  m_abort = false;
+  m_connectionLost = false;
+  CreateThread();
+
   if (!ConnectOSD())
     return false;
 
@@ -1149,21 +1153,6 @@ bool cVNSIAdmin::OnAction(int actionId)
     return true;
   }
 
-  if (actionId == ACTION_SELECT_ITEM)
-  {
-    if (m_window->GetFocusId() == CONTROL_MENU)
-    {
-      const char *tmp = m_window->GetProperty("menu");
-      //if (strncmp(m_window->GetProperty("menu"), "osd", 3) == 0)
-      if (strncmp(tmp, "osd", 3) == 0)
-      {
-#if defined(KODI_GUILIB_API_VERSION)
-        m_window->MarkDirtyRegion();
-#endif
-      }
-    }
-  }
-
   return false;
 }
 
@@ -1348,7 +1337,6 @@ bool cVNSIAdmin::OnResponsePacket(cResponsePacket* resp)
           m_osdRender->DisposeTexture(wnd);
         m_bIsOsdDirty = true;
       }
-      m_window->SetFocusId(CONTROL_MENU);
     }
     else if (resp->getOpCodeID() == VNSI_OSD_MOVEWINDOW)
     {
