@@ -141,30 +141,31 @@ void cVNSIChannelScan::StartScan()
   }
 
   cRequestPacket vrp;
-  cResponsePacket* vresp = NULL;
   uint32_t retCode = VNSI_RET_ERROR;
-  if (!vrp.init(VNSI_SCAN_START))                          goto SCANError;
-  if (!vrp.add_U32(source))                               goto SCANError;
-  if (!vrp.add_U8(m_radioButtonTV->IsSelected()))         goto SCANError;
-  if (!vrp.add_U8(m_radioButtonRadio->IsSelected()))      goto SCANError;
-  if (!vrp.add_U8(m_radioButtonFTA->IsSelected()))        goto SCANError;
-  if (!vrp.add_U8(m_radioButtonScrambled->IsSelected()))  goto SCANError;
-  if (!vrp.add_U8(m_radioButtonHD->IsSelected()))         goto SCANError;
-  if (!vrp.add_U32(m_spinCountries->GetValue()))          goto SCANError;
-  if (!vrp.add_U32(m_spinDVBCInversion->GetValue()))      goto SCANError;
-  if (!vrp.add_U32(m_spinDVBCSymbolrates->GetValue()))    goto SCANError;
-  if (!vrp.add_U32(m_spinDVBCqam->GetValue()))            goto SCANError;
-  if (!vrp.add_U32(m_spinDVBTInversion->GetValue()))      goto SCANError;
-  if (!vrp.add_U32(m_spinSatellites->GetValue()))         goto SCANError;
-  if (!vrp.add_U32(m_spinATSCType->GetValue()))           goto SCANError;
+  vrp.init(VNSI_SCAN_START);
+  vrp.add_U32(source);
+  vrp.add_U8(m_radioButtonTV->IsSelected());
+  vrp.add_U8(m_radioButtonRadio->IsSelected());
+  vrp.add_U8(m_radioButtonFTA->IsSelected());
+  vrp.add_U8(m_radioButtonScrambled->IsSelected());
+  vrp.add_U8(m_radioButtonHD->IsSelected());
+  vrp.add_U32(m_spinCountries->GetValue());
+  vrp.add_U32(m_spinDVBCInversion->GetValue());
+  vrp.add_U32(m_spinDVBCSymbolrates->GetValue());
+  vrp.add_U32(m_spinDVBCqam->GetValue());
+  vrp.add_U32(m_spinDVBTInversion->GetValue());
+  vrp.add_U32(m_spinSatellites->GetValue());
+  vrp.add_U32(m_spinATSCType->GetValue());
 
-  vresp = ReadResult(&vrp);
-  if (!vresp)
-    goto SCANError;
+  {
+    auto vresp = ReadResult(&vrp);
+    if (!vresp)
+      goto SCANError;
 
-  retCode = vresp->extract_U32();
-  if (retCode != VNSI_RET_OK)
-    goto SCANError;
+    retCode = vresp->extract_U32();
+    if (retCode != VNSI_RET_OK)
+      goto SCANError;
+  }
 
   return;
 
@@ -179,10 +180,9 @@ SCANError:
 void cVNSIChannelScan::StopScan()
 {
   cRequestPacket vrp;
-  if (!vrp.init(VNSI_SCAN_STOP))
-    return;
+  vrp.init(VNSI_SCAN_STOP);
 
-  cResponsePacket* vresp = ReadResult(&vrp);
+  auto vresp = ReadResult(&vrp);
   if (!vresp)
     return;
 
@@ -285,23 +285,28 @@ bool cVNSIChannelScan::OnClick(int controlId)
   }
   else if (controlId == BUTTON_START)
   {
-    if (!m_running)
-    {
-      m_running = true;
-      m_stopped = false;
-      m_Canceled = false;
-      m_window->SetProperty("Scanning", "running");
-      m_window->SetControlLabel(BUTTON_START, XBMC->GetLocalizedString(222));
-      StartScan();
+    try {
+      if (!m_running)
+      {
+        m_running = true;
+        m_stopped = false;
+        m_Canceled = false;
+        m_window->SetProperty("Scanning", "running");
+        m_window->SetControlLabel(BUTTON_START, XBMC->GetLocalizedString(222));
+        StartScan();
+      }
+      else if (!m_stopped)
+      {
+        m_stopped = true;
+        m_Canceled = true;
+        StopScan();
+      }
+      else
+        ReturnFromProcessView();
+    } catch (std::exception e) {
+      XBMC->Log(LOG_ERROR, "%s - %s", __FUNCTION__, e.what());
+      return false;
     }
-    else if (!m_stopped)
-    {
-      m_stopped = true;
-      m_Canceled = true;
-      StopScan();
-    }
-    else
-      ReturnFromProcessView();
   }
   return true;
 }
@@ -434,10 +439,9 @@ bool cVNSIChannelScan::ReadCountries()
   //dvdlang = dvdlang.ToUpper();
 
   cRequestPacket vrp;
-  if (!vrp.init(VNSI_SCAN_GETCOUNTRIES))
-    return false;
+  vrp.init(VNSI_SCAN_GETCOUNTRIES);
 
-  cResponsePacket* vresp = ReadResult(&vrp);
+  auto vresp = ReadResult(&vrp);
   if (!vresp)
     return false;
 
@@ -445,7 +449,7 @@ bool cVNSIChannelScan::ReadCountries()
   uint32_t retCode = vresp->extract_U32();
   if (retCode == VNSI_RET_OK)
   {
-    while (!vresp->end())
+    while (vresp->getRemainingLength() >= 4 + 2)
     {
       uint32_t    index     = vresp->extract_U32();
       const char *isoName   = vresp->extract_String();
@@ -453,9 +457,6 @@ bool cVNSIChannelScan::ReadCountries()
       m_spinCountries->AddLabel(longName, index);
       if (dvdlang == isoName)
         startIndex = index;
-
-      delete[] longName;
-      delete[] isoName;
     }
     if (startIndex >= 0)
       m_spinCountries->SetValue(startIndex);
@@ -464,7 +465,6 @@ bool cVNSIChannelScan::ReadCountries()
   {
     XBMC->Log(LOG_ERROR, "%s - Return error after reading countries (%i)", __FUNCTION__, retCode);
   }
-  delete vresp;
   return retCode == VNSI_RET_OK;
 }
 
@@ -474,24 +474,21 @@ bool cVNSIChannelScan::ReadSatellites()
   m_spinSatellites->Clear();
 
   cRequestPacket vrp;
-  if (!vrp.init(VNSI_SCAN_GETSATELLITES))
-    return false;
+  vrp.init(VNSI_SCAN_GETSATELLITES);
 
-  cResponsePacket* vresp = ReadResult(&vrp);
+  auto vresp = ReadResult(&vrp);
   if (!vresp)
     return false;
 
   uint32_t retCode = vresp->extract_U32();
   if (retCode == VNSI_RET_OK)
   {
-    while (!vresp->end())
+    while (vresp->getRemainingLength() >= 4 + 2)
     {
       uint32_t    index     = vresp->extract_U32();
       const char *shortName = vresp->extract_String();
       const char *longName  = vresp->extract_String();
       m_spinSatellites->AddLabel(longName, index);
-      delete[] longName;
-      delete[] shortName;
     }
     m_spinSatellites->SetValue(6);      /* default to Astra 19.2         */
   }
@@ -499,7 +496,6 @@ bool cVNSIChannelScan::ReadSatellites()
   {
     XBMC->Log(LOG_ERROR, "%s - Return error after reading satellites (%i)", __FUNCTION__, retCode);
   }
-  delete vresp;
   return retCode == VNSI_RET_OK;
 }
 
@@ -539,13 +535,11 @@ bool cVNSIChannelScan::OnResponsePacket(cResponsePacket* resp)
   {
     char* str = resp->extract_String();
     m_window->SetControlLabel(LABEL_DEVICE, str);
-    delete[] str;
   }
   else if (requestID == VNSI_SCANNER_TRANSPONDER)
   {
     char* str = resp->extract_String();
     m_window->SetControlLabel(LABEL_TRANSPONDER, str);
-    delete[] str;
   }
   else if (requestID == VNSI_SCANNER_NEWCHANNEL)
   {
@@ -564,8 +558,6 @@ bool cVNSIChannelScan::OnResponsePacket(cResponsePacket* resp)
 
     m_window->AddItem(item, 0);
     GUI->ListItem_destroy(item);
-
-    delete[] str;
   }
   else if (requestID == VNSI_SCANNER_FINISHED)
   {
