@@ -398,6 +398,11 @@ PVR_ERROR cVNSIData::GetTimerInfo(unsigned int timernumber, PVR_TIMER &tag)
     strncpy(tag.strEpgSearchString, epgSearch, sizeof(tag.strEpgSearchString) - 1);
   }
 
+  if (GetProtocol() >= 10)
+  {
+    tag.iParentClientIndex = vresp->extract_U32();
+  }
+
   return PVR_ERROR_NO_ERROR;
 }
 
@@ -455,6 +460,11 @@ bool cVNSIData::GetTimersList(ADDON_HANDLE handle)
         strncpy(tag.strEpgSearchString, epgSearch, sizeof(tag.strEpgSearchString) - 1);
       }
 
+      if (GetProtocol() >= 10)
+      {
+        tag.iParentClientIndex = vresp->extract_U32();
+      }
+
       if (tag.startTime == 0)
 	tag.bStartAnyTime = true;
       if (tag.endTime == 0)
@@ -548,6 +558,12 @@ PVR_ERROR cVNSIData::AddTimer(const PVR_TIMER &timerinfo)
     vrp.add_String(timerinfo.strEpgSearchString);
   }
 
+  if (GetProtocol() >= 10)
+  {
+    vrp.add_U32(timerinfo.iMarginStart*60);
+    vrp.add_U32(timerinfo.iMarginEnd*60);
+  }
+
   auto vresp = ReadResult(&vrp);
   if (vresp == NULL || vresp->noResponse())
   {
