@@ -29,19 +29,17 @@
 class cResponsePacket;
 class cRequestPacket;
 
-class cVNSIData : public cVNSISession, public PLATFORM::CThread
+class cVNSIData : public cVNSISession, public P8PLATFORM::CThread
 {
 public:
 
   cVNSIData();
   virtual ~cVNSIData();
 
-  bool        Open(const std::string& hostname, int port, const char* name = NULL, const std::string& mac = "");
-  bool        Login() override;
-
+  bool Start(const std::string& hostname, int port, const char* name = NULL, const std::string& mac = "");
   bool        SupportChannelScan();
   bool        SupportRecordingsUndelete();
-  bool        EnableStatusInterface(bool onOff);
+  bool        EnableStatusInterface(bool onOff, bool wait = true);
   bool        GetDriveSpace(long long *total, long long *used);
 
   int         GetChannelsCount();
@@ -59,6 +57,7 @@ public:
   PVR_ERROR   DeleteTimer(const PVR_TIMER &timerinfo, bool force = false);
   PVR_ERROR   RenameTimer(const PVR_TIMER &timerinfo, const char *newname);
   PVR_ERROR   UpdateTimer(const PVR_TIMER &timerinfo);
+  PVR_ERROR GetTimerTypes(PVR_TIMER_TYPE types[], int *size);
 
   int         GetRecordingsCount();
   PVR_ERROR   GetRecordingsList(ADDON_HANDLE handle);
@@ -75,7 +74,7 @@ public:
 
 protected:
 
-  virtual void *Process(void);
+  virtual void *Process(void) override;
   virtual bool OnResponsePacket(cResponsePacket *pkt);
 
   void OnDisconnect() override;
@@ -85,14 +84,14 @@ private:
 
   struct SMessage
   {
-    PLATFORM::CEvent event;
+    P8PLATFORM::CEvent event;
     std::unique_ptr<cResponsePacket> pkt;
   };
 
   class Queue {
     typedef std::map<int, SMessage> SMessages;
     SMessages m_queue;
-    PLATFORM::CMutex m_mutex;
+    P8PLATFORM::CMutex m_mutex;
 
   public:
     SMessage &Enqueue(uint32_t serial);
