@@ -71,18 +71,23 @@ bool cVNSIRecording::OpenRecording(const PVR_RECORDING& recinfo)
 
 void cVNSIRecording::Close()
 {
-  if(!IsOpen())
-    return;
+  if(IsOpen())
+  {
+    try {
+      cRequestPacket vrp;
+      vrp.init(VNSI_RECSTREAM_CLOSE);
+      ReadSuccess(&vrp);
+    } catch (std::exception e) {
+      XBMC->Log(LOG_ERROR, "%s - %s", __FUNCTION__, e.what());
+    }
+  }
 
-  cRequestPacket vrp;
-  vrp.init(VNSI_RECSTREAM_CLOSE);
-  ReadSuccess(&vrp);
   cVNSISession::Close();
 }
 
 int cVNSIRecording::Read(unsigned char* buf, uint32_t buf_size)
 {
-  if (ConnectionLost() && !TryReconnect())
+  if (m_connectionLost && TryReconnect() != cVNSISession::CONN_ESABLISHED)
   {
     *buf = 0;
     SleepMs(100);
