@@ -22,14 +22,15 @@
 
 #include <stdint.h>
 #include <string>
-#include "platform/threads/threads.h"
+#include <atomic>
+#include "p8-platform/threads/threads.h"
 
 #include <memory>
 
 class cResponsePacket;
 class cRequestPacket;
 
-namespace PLATFORM
+namespace P8PLATFORM
 {
   class CTcpConnection;
 }
@@ -54,32 +55,40 @@ public:
   const std::string& GetServerName() const { return m_server; }
   const std::string& GetVersion() const { return m_version; }
 
+  enum eCONNECTIONSTATE
+  {
+    CONN_ESABLISHED = 0,
+    CONN_HOST_NOT_REACHABLE,
+    CONN_LOGIN_FAILED,
+    CONN_UNKNOWN
+  };
+
 protected:
 
   void SleepMs(int ms);
 
-  bool TryReconnect();
+  eCONNECTIONSTATE TryReconnect();
   bool IsOpen();
 
   virtual void OnDisconnect();
   virtual void OnReconnect();
 
   virtual void SignalConnectionLost();
-  bool ConnectionLost() const { return m_connectionLost; }
 
   std::string      m_hostname;
   int              m_port;
   std::string      m_name;
-  PLATFORM::CMutex m_mutex;
+  P8PLATFORM::CMutex m_mutex;
   int              m_protocol;
   std::string      m_server;
   std::string      m_version;
+  bool m_connectionLost;
+  std::atomic_bool m_abort;
 
 private:
 
   bool readData(uint8_t* buffer, int totalBytes, int timeout);
 
-  PLATFORM::CTcpConnection *m_socket;
-  PLATFORM::CMutex          m_readMutex;
-  bool                      m_connectionLost;
+  P8PLATFORM::CTcpConnection *m_socket;
+  P8PLATFORM::CMutex          m_readMutex;
 };
