@@ -22,7 +22,7 @@
 #include "responsepacket.h"
 #include "vnsicommand.h"
 #include "tools.h"
-#include "platform/sockets/tcp.h"
+#include "p8-platform/sockets/tcp.h"
 
 #include <stdexcept>
 #include <stdlib.h>
