@@ -34,5 +34,5 @@ uint64_t htonll(uint64_t a);
 #endif
 #endif
 
-#include "kodi/libXBMC_codec.h"
+#include "libXBMC_codec.h"
 #include "xbmc_codec_descriptor.hpp"
